@@ -1,7 +1,7 @@
 import rope.base.ast
 import rope.base.oi.soi
 import rope.base.pynames
-from rope.base import pyobjects, evaluate, astutils, arguments
+from rope.base import pyobjects, evaluate, nameanalyze, arguments
 
 
 def analyze_module(pycore, pymodule, should_analyze, search_subscopes, followed_calls):
@@ -33,11 +33,11 @@ def _analyze_node(pycore, pydefined, should_analyze, search_subscopes, followed_
         if not followed_calls:
             _follow = None
         visitor = SOAVisitor(pycore, pydefined, _follow)
-        for child in rope.base.ast.get_child_nodes(pydefined.get_ast()):
-            rope.base.ast.walk(child, visitor)
+        for child in rope.base.ast.iter_child_nodes(pydefined.get_ast()):
+            visitor.visit(child)
 
 
-class SOAVisitor:
+class SOAVisitor(rope.base.ast.RopeNodeVisitor):
     def __init__(self, pycore, pydefined, follow_callback=None):
         self.pycore = pycore
         self.pymodule = pydefined.get_module()
@@ -51,8 +51,8 @@ class SOAVisitor:
         pass
 
     def _Call(self, node):
-        for child in rope.base.ast.get_child_nodes(node):
-            rope.base.ast.walk(child, self)
+        for child in rope.base.ast.iter_child_nodes(node):
+            self.visit(child)
         primary, pyname = evaluate.eval_node2(self.scope, node.func)
         if pyname is None:
             return
@@ -99,23 +99,23 @@ class SOAVisitor:
         ]
 
     def _AnnAssign(self, node):
-        for child in rope.base.ast.get_child_nodes(node):
-            rope.base.ast.walk(child, self)
+        for child in rope.base.ast.iter_child_nodes(node):
+            self.visit(child)
         visitor = _SOAAssignVisitor()
         nodes = []
 
-        rope.base.ast.walk(node.target, visitor)
+        visitor.visit(node.target)
         nodes.extend(visitor.nodes)
 
         self._evaluate_assign_value(node, nodes, type_hint=node.annotation)
 
     def _Assign(self, node):
-        for child in rope.base.ast.get_child_nodes(node):
-            rope.base.ast.walk(child, self)
+        for child in rope.base.ast.iter_child_nodes(node):
+            self.visit(child)
         visitor = _SOAAssignVisitor()
         nodes = []
         for child in node.targets:
-            rope.base.ast.walk(child, visitor)
+            visitor.visit(child)
             nodes.extend(visitor.nodes)
         self._evaluate_assign_value(node, nodes)
 
@@ -139,7 +139,7 @@ class SOAVisitor:
                 # IDEA: handle `__setslice__`, too
 
 
-class _SOAAssignVisitor(astutils._NodeNameCollector):
+class _SOAAssignVisitor(nameanalyze._NodeNameCollector):
     def __init__(self):
         super().__init__()
         self.nodes = []
