@@ -3,12 +3,18 @@ import shutil
 import sys
 import warnings
 
-import rope.base.fscommands
-import rope.base.resourceobserver as resourceobserver
-from rope.base import exceptions, history, pycore, taskhandle, utils
+import rope.base.fscommands  # Use full qualification for clarity.
+from rope.base import (
+    exceptions,
+    history,
+    pycore,
+    taskhandle,
+    utils,
+)
 from rope.base.exceptions import ModuleNotFoundError
 from rope.base.prefs import Prefs, get_config
 from rope.base.resources import File, Folder, _ResourceMatcher
+import rope.base.resourceobserver as resourceobserver
 
 try:
     import cPickle as pickle
@@ -206,6 +212,7 @@ class Project(_Project):
         """
         if projectroot != "/":
             projectroot = _realpath(projectroot).rstrip("/\\")
+        assert isinstance(projectroot, str)
         self._address = projectroot
         self._ropefolder_name = ropefolder
         if not os.path.exists(self._address):
@@ -273,7 +280,7 @@ class Project(_Project):
 
     def _init_other_parts(self):
         # Forcing the creation of `self.pycore` to register observers
-        self.pycore
+        self.pycore  # pylint: disable=pointless-statement
 
     def is_ignored(self, resource):
         return self.ignored.does_match(resource)
