@@ -30,23 +30,30 @@ import os
 import re
 import warnings
 
-from rope.base import change
-from rope.base import exceptions
-from rope.base import fscommands
+from rope.base import change, exceptions, fscommands
+from pathlib import Path
 
 
-class Resource(object):
+class Resource:
     """Represents files and folders in a project"""
 
     def __init__(self, project, path):
         self.project = project
         self._path = path
 
+    def __repr__(self):
+        return '<{}.{} "{}" at {}>'.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            self.path,
+            hex(id(self)),
+        )
+
     def move(self, new_location):
         """Move resource to `new_location`"""
         self._perform_change(
             change.MoveResource(self, new_location),
-            "Moving <%s> to <%s>" % (self.path, new_location),
+            f"Moving <{self.path}> to <{new_location}>",
         )
 
     def remove(self):
@@ -86,6 +93,11 @@ class Resource(object):
         """Return the file system path of this resource"""
         return self.project._get_resource_path(self.path)
 
+    @property
+    def pathlib(self):
+        """Return the file as a pathlib path."""
+        return Path(self.real_path)
+
     def __eq__(self, obj):
         return self.__class__ == obj.__class__ and self.path == obj.path
 
@@ -106,7 +118,7 @@ class File(Resource):
 
     def __init__(self, project, name):
         self.newlines = None
-        super(File, self).__init__(project, name)
+        super().__init__(project, name)
 
     def read(self):
         data = self.read_bytes()
@@ -131,7 +143,7 @@ class File(Resource):
         try:
             if contents == self.read():
                 return
-        except IOError:
+        except OSError:
             pass
         self._perform_change(
             change.ChangeContents(self, contents), "Writing file <%s>" % self.path
@@ -148,7 +160,7 @@ class Folder(Resource):
     """Represents a folder"""
 
     def __init__(self, project, name):
-        super(Folder, self).__init__(project, name)
+        super().__init__(project, name)
 
     def is_folder(self):
         return True
@@ -216,7 +228,7 @@ class Folder(Resource):
         self.parent.create_folder(self.name)
 
 
-class _ResourceMatcher(object):
+class _ResourceMatcher:
     def __init__(self):
         self.patterns = []
         self._compiled_patterns = []
@@ -246,9 +258,7 @@ class _ResourceMatcher(object):
             if pattern.match(resource.path):
                 return True
         path = os.path.join(resource.project.address, *resource.path.split("/"))
-        if os.path.islink(path):
-            return True
-        return False
+        return os.path.islink(path)
 
     @property
     def compiled_patterns(self):
