@@ -1,9 +1,11 @@
-import rope.base.codeanalyze
-import rope.base.evaluate
-from rope.base import exceptions
-from rope.base import libutils
-from rope.base import utils
-from rope.base import worder
+from rope.base import (
+    codeanalyze,
+    exceptions,
+    evaluate,
+    libutils,
+    utils,
+    worder,
+)
 from rope.base.codeanalyze import ArrayLinesAdapter, LogicalLineFinder
 
 
@@ -33,7 +35,7 @@ class FixSyntax:
                 )
             except exceptions.ModuleSyntaxError as e:
                 if msg is None:
-                    msg = "{}:{} {}".format(e.filename, e.lineno, e.message_)
+                    msg = f"{e.filename}:{e.lineno} {e.message_}"
                 if tries < self.maxfixes:
                     tries += 1
                     self.commenter.comment(e.lineno)
@@ -57,13 +59,13 @@ class FixSyntax:
             expression = expression.replace("\\\n", " ").replace("\n", " ")
             lineno = self.code.count("\n", 0, offset)
             scope = pymodule.get_scope().get_inner_scope_for_line(lineno)
-            return rope.base.evaluate.eval_str(scope, expression)
+            return evaluate.eval_str(scope, expression)
 
         new_code = pymodule.source_code
 
         def new_pyname():
-            newoffset = self.commenter.transfered_offset(offset)
-            return rope.base.evaluate.eval_location(pymodule, newoffset)
+            newoffset = self.commenter.transferred_offset(offset)
+            return evaluate.eval_location(pymodule, newoffset)
 
         if new_code.startswith(self.code[: offset + 1]):
             return new_pyname()
@@ -97,7 +99,7 @@ class _Commenter:
             self._set(line, self.lines[start])
         self._fix_incomplete_try_blocks(lineno, indents)
 
-    def transfered_offset(self, offset):
+    def transferred_offset(self, offset):
         lineno = self.code.count("\n", 0, offset)
         diff = sum(self.diffs[:lineno])
         return offset + diff
@@ -129,9 +131,7 @@ class _Commenter:
         last_indents = indents
         while block_start > 0:
             block_start = (
-                rope.base.codeanalyze.get_block_start(
-                    ArrayLinesAdapter(self.lines), block_start
-                )
+                codeanalyze.get_block_start(ArrayLinesAdapter(self.lines), block_start)
                 - 1
             )
             if self.lines[block_start].strip().startswith("try:"):
@@ -186,4 +186,4 @@ def _logical_start(lines, lineno, check_prev=False):
 
 
 def _get_line_indents(line):
-    return rope.base.codeanalyze.count_line_indents(line)
+    return codeanalyze.count_line_indents(line)
