@@ -5,14 +5,14 @@ based on inputs.
 
 """
 from rope.base import (
-    pyobjects,
     codeanalyze,
-    exceptions,
-    pynames,
-    taskhandle,
     evaluate,
-    worder,
+    exceptions,
     libutils,
+    pynames,
+    pyobjects,
+    taskhandle,
+    worder,
 )
 from rope.base.change import ChangeSet, ChangeContents, MoveResource
 from rope.refactor import importutils, rename, occurrences, sourceutils, functionutils
@@ -706,9 +706,9 @@ class _MoveTools:
 
     def occurs_in_module(self, pymodule=None, resource=None, imports=True):
         finder = self._create_finder(imports)
-        for occurrence in finder.find_occurrences(pymodule=pymodule, resource=resource):
-            return True
-        return False
+        occurrences = finder.find_occurrences(pymodule=pymodule, resource=resource)
+        sentinel = object()
+        return next(occurrences, sentinel) is not sentinel
 
     def _create_finder(self, imports):
         return occurrences.create_finder(
