@@ -5,14 +5,8 @@ import warnings
 from itertools import chain
 
 from rope.base import ast, codeanalyze, exceptions
-from rope.base.utils import pycompat
 
 
-try:
-    basestring
-except NameError:
-    basestring = (str, bytes)
-
 COMMA_IN_WITH_PATTERN = re.compile(r"\(.*?\)|(,)")
 
 
@@ -96,7 +90,7 @@ class _PatchingASTWalker:
         )
         node.region = (self.source.offset, self.source.offset)
         if self.children:
-            node.sorted_children = ast.get_children(node)
+            node.sorted_children = [child for field, child in ast.iter_fields(node)]
 
     def _handle(self, node, base_children, eat_parens=False, eat_spaces=False):
         if hasattr(node, "region"):
@@ -222,7 +216,7 @@ class _PatchingASTWalker:
         start = 0
         opens = 0
         for child in children:
-            if not isinstance(child, basestring):
+            if not isinstance(child, (str, bytes)):
                 continue
             if child == "" or child[0] in "'\"":
                 continue
@@ -384,7 +378,7 @@ class _PatchingASTWalker:
         self._handle(node, ["del"] + self._child_nodes(node.targets, ","))
 
     def _Constant(self, node):
-        if isinstance(node.value, basestring):
+        if isinstance(node.value, (str, bytes)):
             self._handle(node, [self.String])
             return
 
@@ -526,14 +520,15 @@ class _PatchingASTWalker:
     def _ImportFrom(self, node):
         children = ["from"]
         if node.level:
-            children.append("." * node.level)
-        # see comment at rope.base.ast.walk
-        children.extend([node.module or "", "import"])
+            children.extend("." * node.level)
+        if node.module:
+            children.extend(node.module.split("."))
+        children.append("import")
         children.extend(self._child_nodes(node.names, ","))
         self._handle(node, children)
 
     def _alias(self, node):
-        children = [node.name]
+        children = node.name.split(".")
         if node.asname:
             children.extend(["as", node.asname])
         self._handle(node, children)
@@ -541,7 +536,7 @@ class _PatchingASTWalker:
     def _handle_function_def_node(self, node, is_async):
         children = []
         try:
-            decorators = getattr(node, "decorator_list")
+            decorators = node.decorator_list
         except AttributeError:
             decorators = getattr(node, "decorators", None)
         if decorators:
@@ -574,11 +569,11 @@ class _PatchingASTWalker:
         if node.vararg is not None:
             if args:
                 children.append(",")
-            children.extend(["*", pycompat.get_ast_arg_arg(node.vararg)])
+            children.extend(["*", node.vararg.arg])
         if node.kwarg is not None:
             if args or node.vararg is not None:
                 children.append(",")
-            children.extend(["**", pycompat.get_ast_arg_arg(node.kwarg)])
+            children.extend(["**", node.kwarg.arg])
         self._handle(node, children)
 
     def _add_args_to_children(self, children, arg, default):
@@ -853,7 +848,7 @@ class _PatchingASTWalker:
 
         if is_async:
             children.extend(["async"])
-        for item in pycompat.get_ast_with_items(node):
+        for item in node.items:
             children.extend([self.with_or_comma_context_manager, item.context_expr])
             if item.optional_vars:
                 children.extend(["as", item.optional_vars])
@@ -927,9 +922,9 @@ class _Source:
                     break
                 else:
                     self._skip_comment()
-        except (ValueError, TypeError) as e:
+        except (ValueError, TypeError) as e:  # noqa
             raise MismatchedTokenError(
-                "Token <{}> at {} cannot be matched".format(token, self._get_location())
+                f"Token <{token}> at {self._get_location()} cannot be matched"
             )
         self.offset = new_offset + len(token)
         return (new_offset, self.offset)
@@ -943,8 +938,14 @@ class _Source:
         if _Source._string_pattern is None:
             string_pattern = codeanalyze.get_string_pattern()
             formatted_string_pattern = codeanalyze.get_formatted_string_pattern()
-            original = r"(?:{})|(?:{})".format(string_pattern, formatted_string_pattern)
-            pattern = r"({})((\s|\\\n|#[^\n]*\n)*({}))*".format(original, original)
+            original = r"(?:{})|(?:{})".format(
+                string_pattern,
+                formatted_string_pattern,
+            )
+            pattern = r"({})((\s|\\\n|#[^\n]*\n)*({}))*".format(
+                original,
+                original,
+            )
             _Source._string_pattern = re.compile(pattern)
         repattern = _Source._string_pattern
         return self._consume_pattern(repattern, end)
